#
# spec file for package elementary
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           elementary
Version:	    1.7.4
Release:        1.1
License:        LGPL-2.1
Summary:        The widget set for enlightenment
Url:            http://enlightenment.org/
Group:          System/Libraries
Source:         %{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE elementary-0.7.0.63840-desktop.patch
Patch0:         elementary-0.7.0.63840-desktop.patch
BuildRequires:  doxygen
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRequires:  e_dbus-devel >= %version
BuildRequires:  ecore-devel >= %version
BuildRequires:  edje-devel >= %version
BuildRequires:  eet-devel >= %version
BuildRequires:  eina-devel >= %version
BuildRequires:  eio-devel >= %version
BuildRequires:  embryo-devel >= %version
BuildRequires:  emotion-devel >= %version
BuildRequires:  ethumb-devel >= %version
BuildRequires:  evas-devel >= %version
BuildRequires:  gettext-devel
BuildRequires:  ImageMagick
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  libX11-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif

%description
Set of widgets for enlightenment focused on touch devices

%package -n libelementary1
Summary:        Elementary Dynamic Libraries
Group:          System/Libraries

%description -n libelementary1
Headers, static libraries, test programs and documentation for elementary

%package devel
Summary:        Elementary development package
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       e_dbus-devel >= %version
Requires:       ecore-devel >= %version
Requires:       edje-devel >= %version
Requires:       eet-devel >= %version
Requires:       eina-devel >= %version
Requires:       eio-devel >= %version
Requires:       embryo-devel >= %version
Requires:       emotion-devel >= %version
Requires:       ethumb-devel >= %version
Requires:       evas-devel >= %version
Requires:       gettext-devel
Requires:       libelementary1 = %{version}
Requires:       libX11-devel

%description devel
Development files for Elementary library.

%package doc-html
Summary:        HTML documentation of Elementary
Group:          Documentation/HTML

%description doc-html
Documentation of Elementary library in form of HTML pages.

%package doc-man
Summary:        Man documentation of Elementary
Group:          Documentation/Man

%description doc-man
Documentation of Elementary library in form of man pages.

%package examples
Summary:        Elementary examples
Group:          Documentation/Other

%description examples
Examples of usage of Elementary library.

%prep
%setup -q
%patch0

%build
# fake time used for documentation
FAKE_DOCDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y')
FAKE_DOCYEAR=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%Y')
FAKE_DOCDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y %T')
sed -i "s/\$datetime/$FAKE_DOCDATETIME/g;s/\$date/$FAKE_DOCDATE/g;s/\$year/$FAKEDOCYEAR/g" doc/*.html

%configure --disable-static --disable-silent-rules --enable-install-examples
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%buildroot"

# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}
/bin/cp -vr doc/html %{buildroot}%{_docdir}/%{name}
echo "Copying MAN pages"
/bin/cp -vr doc/man/ %{buildroot}%{_mandir}/
# fix line endings
find %{buildroot}%{_docdir} -name '*.eps' | xargs sed -i 's@\r@\n@g'
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%fdupes -s %{buildroot}%{_mandir}
%endif

mkdir -p  %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/
mv %{buildroot}%{_datadir}/icons/elementary.png  %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/
find %{buildroot}%{_libdir} -name '*.la' -exec rm -v {} +
%find_lang %{name}
%if 0%{?suse_version}
%suse_update_desktop_file -n %{buildroot}%{_datadir}/applications/elementary_config.desktop
%suse_update_desktop_file -n %{buildroot}%{_datadir}/applications/elementary_test.desktop
%endif

%post -n libelementary1 -p /sbin/ldconfig
%postun -n libelementary1 -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root)
%if 0%{?sles_version}
# FIXME: this is probably not standard dir
%dir %{_datadir}/locale/ko_KR
%dir %{_datadir}/locale/ko_KR/LC_MESSAGES
%endif
%{_bindir}/elementary*
%{_datadir}/elementary
%exclude %{_datadir}/elementary/examples
%{_datadir}/icons/hicolor/
%{_datadir}/applications/elementary*
%{_libdir}/edje
%{_libdir}/elementary
%{_libdir}/elementary_testql.so

%files -n libelementary1
%defattr(-,root,root)
%{_libdir}/libelementary.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/libelementary.so
%{_libdir}/pkgconfig/elementary.pc
%{_includedir}/elementary-1/

%files doc-html
%defattr(-, root, root)
%{_docdir}/%{name}

%files doc-man
%defattr(-, root, root)
%{_mandir}/*/*

%files examples
%defattr(-, root, root)
%{_datadir}/elementary/examples

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - Version:1.7.4-1.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 1.7.4
  Changes since Elementary 1.7.3:
  * Fix the naviframe title_set problem that caused the title
    visible status reset
  * Make sure data is not NULL in elm_interface_scrollable.
  * Correctly handle failure case in _x11_notify_handler_image.
  * Fix missuse of EINA_INLIST_FOREACH in elm_transit.c.
  * Now, dummy object is always smart member of naviframe.
  * Fix the popup that returned invalid action buttons.
  * Fix the naviframe to not have crash even if user deletes the
    naviframe in the transition finished cb.
  * Fix Don't elm_transit image animation use the image preloading
    to avoid image flickering.
  * Fix the image to show the image right now if the image
    preloading is disabled.
  * Fix small memory leak in elm_map error path
  * Fix memory leak in _item_tag_remove of elm_entry.
* Fri Dec 21 2012 sleep_walker@suse.cz
- build and package documentation, package examples
* Tue Dec 11 2012 sleep_walker@suse.cz
- remove lua dependency completely as it is not present in configure.ac (why was it there?)
* Sat Dec  8 2012 simon@simotek.net
- Bump to 1.7.3
- 1.7.3 is a bugfix release to coincide with the beta release of efl
* Sat Nov 24 2012 sleep_walker@suse.cz
- require the same version or higher for EFL libraries
* Fri Nov 23 2012 simon@simotek.net
- bump to 1.7.2
- 1.7.2 is required to build and use the latest e17 alpha's
* Thu Nov 22 2012 sleep_walker@suse.cz
- license fix
- spec clean up
- remove autoupdate entries from changelog
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove autoreconf as it is not needed for release
* Sun Oct 21 2012 simon@simotek.net
- bump to 1.7.1
* Wed Sep 19 2012 sleep_walker@suse.cz
- use 'make install DESTDIR=%%buildroot' for fedora, mandriva, centos
* Thu Mar 29 2012 sleep_walker@suse.cz
- update to version 1.0.0
* Mon Mar  5 2012 sleep_walker@suse.cz
- stupid fix of previous commit
* Thu Feb 23 2012 sleep_walker@suse.cz
- elementary-devel now requires elementary
* Fri Dec 30 2011 sleep_walker@suse.cz
- explicitly BuildRequire autoconf, automake and libtool
* Fri Dec 30 2011 tcech@suse.com
- disable autoreconf for CentOS 5
* Wed Nov  2 2011 sleep_walker@suse.cz
- elementary now requires e_dbus
* Wed Nov  2 2011 tcech@suse.com
- elementary now requires ethumb
* Tue Nov  1 2011 tcech@suse.com
- elementary now requires emotion
* Sat Oct 22 2011 tcech@suse.com
- do not run autoreconf for SLE_10_SDK
* Tue Oct 18 2011 tcech@suse.com
- add dependencies needed for build as required for devel package
* Sun Oct 16 2011 tcech@suse.com
- add suse_update_desktop_file
* Sat Oct 15 2011 tcech@suse.com
- add embryo-devel and lua-devel to buildrequires
* Wed Oct  5 2011 tcech@suse.com
- another patch for desktop files
* Wed Oct  5 2011 jreidinger@suse.com
- patch already integrated, so remove it
* Tue Oct  4 2011 tcech@suse.com
- add gettext-devel dependency
* Tue Oct  4 2011 tcech@suse.com
- add autoreconf to fix openSUSE 11.3 builds
* Tue Oct  4 2011 tcech@suse.com
- fix translations
- remove suse specific desktop file update and file patch for
  upstream instead
- run configure just once
* Mon Oct  3 2011 jreidinger@suse.com
- fix suse specific update desktop files
* Wed Sep 28 2011 tcech@suse.com
- change pkgconfig dependencies to package names
* Sat Feb  5 2011 dimstar@opensuse.org
- Initial package, version 0.7.0.55225
